==> haskell-pandoc-lua-engine-0.2.1.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-lua-engine
version:              0.2.1.2
visibility:           public
id:                   pandoc-lua-engine-0.2.1.2-4axPO82YCCxDg1jhqFCUGZ
key:                  pandoc-lua-engine-0.2.1.2-4axPO82YCCxDg1jhqFCUGZ
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  397fdca8012221431d1088d7f8934855
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.2-4axPO82YCCxDg1jhqFCUGZ
depends:
    SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    aeson-2.1.2.1-2DC8oo6JY6hDnCPVtrY9Cs base-4.16.4.0
    bytestring-0.11.4.0 citeproc-0.8.1-2JhRYsXQNYyL7PZAyFdlpM
    containers-0.6.5.1 data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    doclayout-0.4.0.1-L9c8hIaeShrDC36qRM1nkn
    doctemplates-0.11-FTMrnQmDOVvWaKQwD6pkI exceptions-0.10.4
    hslua-2.3.0-57yJyOyndx8LqyVPJne6JH
    hslua-module-doclayout-1.1.0-AsQ6OXCgF0vHEZg1jlPskP
    hslua-module-path-1.1.0-57WcOH0AJKkKRPBTGugk6A
    hslua-module-system-1.1.0.1-5JLSw3OQJaEIETj3G0VHU3
    hslua-module-text-1.1.0.1-G2ynEMbZaAoJN5tT4Qgfzn
    hslua-module-version-1.1.0-KIJYFn1HDi8A0ifghc8kPt
    hslua-module-zip-1.1.1-FNb3jJmSryzE3xlZdFbnKv
    hslua-repl-0.1.2-HBlijgd1rwSEzOiInLwJQA
    lpeg-1.0.4-lSKQZSeLP7Fvt2MvL7NHd mtl-2.2.2
    pandoc-3.1.8-FI2HaFVRHDn4BE9r2SMlZA
    pandoc-lua-marshal-0.2.3-DZ3EdY7VGjNGRg4OM3VTUW
    pandoc-types-1.23.1-9KdnYvA2vR19pn6O9XFre7 parsec-3.1.15.0
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-lua-engine-0.2.1.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-lua-engine
version:              0.2.1.2
visibility:           public
id:                   pandoc-lua-engine-0.2.1.2-CRR70VFrL15BGBZ1LoZVEm
key:                  pandoc-lua-engine-0.2.1.2-CRR70VFrL15BGBZ1LoZVEm
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  4e2a266c87b6574f3107dcda7535097d
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.2-CRR70VFrL15BGBZ1LoZVEm
depends:
    SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    aeson-2.1.2.1-2DC8oo6JY6hDnCPVtrY9Cs base-4.16.4.0
    bytestring-0.11.4.0 citeproc-0.8.1-2JhRYsXQNYyL7PZAyFdlpM
    containers-0.6.5.1 data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    doclayout-0.4.0.1-L9c8hIaeShrDC36qRM1nkn
    doctemplates-0.11-FTMrnQmDOVvWaKQwD6pkI exceptions-0.10.4
    hslua-2.3.0-57yJyOyndx8LqyVPJne6JH
    hslua-module-doclayout-1.1.0-AsQ6OXCgF0vHEZg1jlPskP
    hslua-module-path-1.1.0-57WcOH0AJKkKRPBTGugk6A
    hslua-module-system-1.1.0.1-5JLSw3OQJaEIETj3G0VHU3
    hslua-module-text-1.1.0.1-G2ynEMbZaAoJN5tT4Qgfzn
    hslua-module-version-1.1.0-KIJYFn1HDi8A0ifghc8kPt
    hslua-module-zip-1.1.1-2r3or1q07UeKPWgxcCfy23
    hslua-repl-0.1.2-HBlijgd1rwSEzOiInLwJQA
    lpeg-1.0.4-lSKQZSeLP7Fvt2MvL7NHd mtl-2.2.2
    pandoc-3.1.8-LGLBoH1yKOk3agcJM1b3F6
    pandoc-lua-marshal-0.2.3-DZ3EdY7VGjNGRg4OM3VTUW
    pandoc-types-1.23.1-9KdnYvA2vR19pn6O9XFre7 parsec-3.1.15.0
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
